==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/de/dcc/vehicle__gui_8h.js <==
var vehicle__gui_8h =
[
    [ "VehicleCellSize", "dc/d1d/structVehicleCellSize.html", "dc/d1d/structVehicleCellSize" ],
    [ "TrainDetailsWindowTabs", "de/dcc/vehicle__gui_8h.html#a4c3889b9c37d65e2c97ccf5c4c81f91a", [
      [ "TDW_TAB_CARGO", "de/dcc/vehicle__gui_8h.html#a4c3889b9c37d65e2c97ccf5c4c81f91aacb301035aff026a5ad00024bc5a476f0", null ],
      [ "TDW_TAB_INFO", "de/dcc/vehicle__gui_8h.html#a4c3889b9c37d65e2c97ccf5c4c81f91aa817dbd33fbc6519ea85a598886f12e4a", null ],
      [ "TDW_TAB_CAPACITY", "de/dcc/vehicle__gui_8h.html#a4c3889b9c37d65e2c97ccf5c4c81f91aa2c5a1f78251d08e703fa59091d5b6a69", null ],
      [ "TDW_TAB_TOTALS", "de/dcc/vehicle__gui_8h.html#a4c3889b9c37d65e2c97ccf5c4c81f91aa45f2fb579d0f09567c197ca99e26598c", null ]
    ] ],
    [ "VehicleInvalidateWindowData", "de/dcc/vehicle__gui_8h.html#a8033b9e49cff3a0804118576c26c3a0c", [
      [ "VIWD_REMOVE_ALL_ORDERS", "de/dcc/vehicle__gui_8h.html#a8033b9e49cff3a0804118576c26c3a0caf091dbb4f630bd86c985c02b3a230954", null ],
      [ "VIWD_MODIFY_ORDERS", "de/dcc/vehicle__gui_8h.html#a8033b9e49cff3a0804118576c26c3a0ca9f10c7e71e64d66941b731407f3b676d", null ],
      [ "VIWD_CONSIST_CHANGED", "de/dcc/vehicle__gui_8h.html#a8033b9e49cff3a0804118576c26c3a0ca2cb6b7e2bc64f38f37fed5ff583b6f94", null ],
      [ "VIWD_AUTOREPLACE", "de/dcc/vehicle__gui_8h.html#a8033b9e49cff3a0804118576c26c3a0ca4da85aea6749fa90c9fda6dc1abe32a1", null ]
    ] ],
    [ "CheckClickOnVehicle", "de/dcc/vehicle__gui_8h.html#ae1488efae7d9be7c8a951a99fc812d51", null ],
    [ "DrawAircraftImage", "de/dcc/vehicle__gui_8h.html#a0695c981c1ddb5de61a77762ac5160b4", null ],
    [ "DrawRoadVehImage", "de/dcc/vehicle__gui_8h.html#a0b5f80c868bc95a4536a0b5d7964e617", null ],
    [ "DrawShipImage", "de/dcc/vehicle__gui_8h.html#a06ecc411a15e0b4681b7e9b7dead8faa", null ],
    [ "DrawTrainImage", "de/dcc/vehicle__gui_8h.html#a91fc56a8928f1389d776d042488467db", null ],
    [ "DrawVehicleImage", "de/dcc/vehicle__gui_8h.html#ae1c518ed16f8a57e0f1672bc4e9af995", null ],
    [ "DrawVehiclePurchaseInfo", "de/dcc/vehicle__gui_8h.html#a3cdbb7ce3801bffff2b080a5070b9f13", null ],
    [ "GetCargoSubtypeText", "de/dcc/vehicle__gui_8h.html#a13f03edf5c8638aeba14a7cd59850ffe", null ],
    [ "GetSingleVehicleWidth", "de/dcc/vehicle__gui_8h.html#a069008a8c9e80ead5692354a1edff071", null ],
    [ "GetVehicleHeight", "de/dcc/vehicle__gui_8h.html#a111b9b1b0820a85e3aabeed236f87fa6", null ],
    [ "GetVehicleImageCellSize", "de/dcc/vehicle__gui_8h.html#af6cea10e1af696ed78fb74ceffe598be", null ],
    [ "GetVehicleWidth", "de/dcc/vehicle__gui_8h.html#a13bcac85aff0a1497da6f06a68625dcb", null ],
    [ "GetWindowClassForVehicleType", "de/dcc/vehicle__gui_8h.html#a1b39f3b1947ddac29516c3205332d0ae", null ],
    [ "SetMouseCursorVehicle", "de/dcc/vehicle__gui_8h.html#aab225565bdaca959c9e1e30dfaa58c83", null ],
    [ "ShowBuildVehicleWindow", "de/dcc/vehicle__gui_8h.html#a8f8c8dda0e71ae7d40459cd7df3ca4d0", null ],
    [ "ShowRefitOptionsList", "de/dcc/vehicle__gui_8h.html#a5cbbef3b22906374d46aee7f77fc8e2c", null ],
    [ "ShowVehicleListWindow", "de/dcc/vehicle__gui_8h.html#aee92626c9ae972dd44f367010709a61e", null ],
    [ "ShowVehicleListWindow", "de/dcc/vehicle__gui_8h.html#afb48808786b1d7e2eed0766a009f3f0a", null ],
    [ "ShowVehicleListWindow", "de/dcc/vehicle__gui_8h.html#a5e05ed41f07f45f9478cca1161147b6c", null ],
    [ "ShowVehicleListWindow", "de/dcc/vehicle__gui_8h.html#a3e8ec09a6006b1134a1674842d901d12", null ],
    [ "ShowVehicleRefitWindow", "de/dcc/vehicle__gui_8h.html#add9315db068b9d8e653e7eabc8b278e1", null ],
    [ "ShowVehicleViewWindow", "de/dcc/vehicle__gui_8h.html#a32d5b24c6c8d443867d3c3339e83172e", null ],
    [ "StartStopVehicle", "de/dcc/vehicle__gui_8h.html#aa91cd98a84ae42ab9c4f0ea1fe76f109", null ],
    [ "VehicleClicked", "de/dcc/vehicle__gui_8h.html#aa7dde968886749e6c004653067eb15ff", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/de/dcc/vehicle__gui_8h.js <==
var vehicle__gui_8h =
[
    [ "TestedEngineDetails", "d4/d97/structTestedEngineDetails.html", "d4/d97/structTestedEngineDetails" ],
    [ "VehicleCellSize", "dc/d1d/structVehicleCellSize.html", "dc/d1d/structVehicleCellSize" ],
    [ "TrainDetailsWindowTabs", "de/dcc/vehicle__gui_8h.html#a4c3889b9c37d65e2c97ccf5c4c81f91a", [
      [ "TDW_TAB_CARGO", "de/dcc/vehicle__gui_8h.html#a4c3889b9c37d65e2c97ccf5c4c81f91aacb301035aff026a5ad00024bc5a476f0", null ],
      [ "TDW_TAB_INFO", "de/dcc/vehicle__gui_8h.html#a4c3889b9c37d65e2c97ccf5c4c81f91aa817dbd33fbc6519ea85a598886f12e4a", null ],
      [ "TDW_TAB_CAPACITY", "de/dcc/vehicle__gui_8h.html#a4c3889b9c37d65e2c97ccf5c4c81f91aa2c5a1f78251d08e703fa59091d5b6a69", null ],
      [ "TDW_TAB_TOTALS", "de/dcc/vehicle__gui_8h.html#a4c3889b9c37d65e2c97ccf5c4c81f91aa45f2fb579d0f09567c197ca99e26598c", null ]
    ] ],
    [ "VehicleInvalidateWindowData", "de/dcc/vehicle__gui_8h.html#a8033b9e49cff3a0804118576c26c3a0c", [
      [ "VIWD_REMOVE_ALL_ORDERS", "de/dcc/vehicle__gui_8h.html#a8033b9e49cff3a0804118576c26c3a0caf091dbb4f630bd86c985c02b3a230954", null ],
      [ "VIWD_MODIFY_ORDERS", "de/dcc/vehicle__gui_8h.html#a8033b9e49cff3a0804118576c26c3a0ca9f10c7e71e64d66941b731407f3b676d", null ],
      [ "VIWD_CONSIST_CHANGED", "de/dcc/vehicle__gui_8h.html#a8033b9e49cff3a0804118576c26c3a0ca2cb6b7e2bc64f38f37fed5ff583b6f94", null ],
      [ "VIWD_AUTOREPLACE", "de/dcc/vehicle__gui_8h.html#a8033b9e49cff3a0804118576c26c3a0ca4da85aea6749fa90c9fda6dc1abe32a1", null ]
    ] ],
    [ "CheckClickOnVehicle", "de/dcc/vehicle__gui_8h.html#a35028b429a622d26b889ca49d7caafcf", null ],
    [ "DrawAircraftImage", "de/dcc/vehicle__gui_8h.html#a0695c981c1ddb5de61a77762ac5160b4", null ],
    [ "DrawRoadVehImage", "de/dcc/vehicle__gui_8h.html#a0b5f80c868bc95a4536a0b5d7964e617", null ],
    [ "DrawShipImage", "de/dcc/vehicle__gui_8h.html#a06ecc411a15e0b4681b7e9b7dead8faa", null ],
    [ "DrawTrainImage", "de/dcc/vehicle__gui_8h.html#a91fc56a8928f1389d776d042488467db", null ],
    [ "DrawVehicleImage", "de/dcc/vehicle__gui_8h.html#ae1c518ed16f8a57e0f1672bc4e9af995", null ],
    [ "DrawVehiclePurchaseInfo", "de/dcc/vehicle__gui_8h.html#a7d68915383294d85808a4c53051f3f79", null ],
    [ "GetCargoSubtypeText", "de/dcc/vehicle__gui_8h.html#a13f03edf5c8638aeba14a7cd59850ffe", null ],
    [ "GetSingleVehicleWidth", "de/dcc/vehicle__gui_8h.html#a069008a8c9e80ead5692354a1edff071", null ],
    [ "GetVehicleHeight", "de/dcc/vehicle__gui_8h.html#a111b9b1b0820a85e3aabeed236f87fa6", null ],
    [ "GetVehicleImageCellSize", "de/dcc/vehicle__gui_8h.html#af6cea10e1af696ed78fb74ceffe598be", null ],
    [ "GetVehicleWidth", "de/dcc/vehicle__gui_8h.html#a13bcac85aff0a1497da6f06a68625dcb", null ],
    [ "GetWindowClassForVehicleType", "de/dcc/vehicle__gui_8h.html#a1b39f3b1947ddac29516c3205332d0ae", null ],
    [ "SetMouseCursorVehicle", "de/dcc/vehicle__gui_8h.html#aab225565bdaca959c9e1e30dfaa58c83", null ],
    [ "ShowBuildVehicleWindow", "de/dcc/vehicle__gui_8h.html#a8f8c8dda0e71ae7d40459cd7df3ca4d0", null ],
    [ "ShowRefitOptionsList", "de/dcc/vehicle__gui_8h.html#a5cbbef3b22906374d46aee7f77fc8e2c", null ],
    [ "ShowVehicleListWindow", "de/dcc/vehicle__gui_8h.html#afb48808786b1d7e2eed0766a009f3f0a", null ],
    [ "ShowVehicleListWindow", "de/dcc/vehicle__gui_8h.html#a5e05ed41f07f45f9478cca1161147b6c", null ],
    [ "ShowVehicleListWindow", "de/dcc/vehicle__gui_8h.html#a3e8ec09a6006b1134a1674842d901d12", null ],
    [ "ShowVehicleListWindow", "de/dcc/vehicle__gui_8h.html#aee92626c9ae972dd44f367010709a61e", null ],
    [ "ShowVehicleRefitWindow", "de/dcc/vehicle__gui_8h.html#add9315db068b9d8e653e7eabc8b278e1", null ],
    [ "ShowVehicleViewWindow", "de/dcc/vehicle__gui_8h.html#a32d5b24c6c8d443867d3c3339e83172e", null ],
    [ "StartStopVehicle", "de/dcc/vehicle__gui_8h.html#aa91cd98a84ae42ab9c4f0ea1fe76f109", null ],
    [ "VehicleClicked", "de/dcc/vehicle__gui_8h.html#aa7dde968886749e6c004653067eb15ff", null ]
];
